"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const http_status_codes_1 = __importDefault(require("http-status-codes"));
const method_handler_1 = require("./method-handler");
const method_result_1 = require("../method-result");
describe("Method Handler", function () {
    class DummyController {
    }
    const dummyController = new DummyController();
    it("forwards thrown errors to express", function () {
        return __awaiter(this, void 0, void 0, function* () {
            const err = new Error("This is a test error");
            const method = () => {
                throw err;
            };
            const metadata = createMethodMetadata();
            const handler = new method_handler_1.MethodHandler(method, metadata, dummyController);
            const req = createRequest();
            const res = createResponse();
            const next = jest.fn();
            yield handler.handleRequest(req, res, next);
            expect(next).toBeCalledWith(err);
        });
    });
    it("forwards thrown async errors to express", function () {
        return __awaiter(this, void 0, void 0, function* () {
            const err = new Error("This is a test error");
            const method = () => __awaiter(this, void 0, void 0, function* () {
                yield Promise.resolve(1);
                throw err;
            });
            const metadata = createMethodMetadata();
            const handler = new method_handler_1.MethodHandler(method, metadata, dummyController);
            const req = createRequest();
            const res = createResponse();
            const next = jest.fn();
            yield handler.handleRequest(req, res, next);
            expect(next).toBeCalledWith(err);
        });
    });
    describe("Request Validation", function () {
        it("permits any body when no validation is specified", function () {
            return __awaiter(this, void 0, void 0, function* () {
                const method = jest.fn().mockReturnValue({});
                const metadata = createMethodMetadata();
                const handler = new method_handler_1.MethodHandler(method, metadata, dummyController);
                const req = createRequest({
                    body: 42,
                });
                const res = createResponse();
                const next = jest.fn();
                yield handler.handleRequest(req, res, next);
                expect(next).not.toBeCalled();
            });
        });
        it("returns BAD_REQUEST if no body is specified when a body is required", function () {
            return __awaiter(this, void 0, void 0, function* () {
                const method = jest.fn().mockReturnValue({});
                const metadata = createMethodMetadata({
                    request: {
                        required: true,
                    },
                });
                const handler = new method_handler_1.MethodHandler(method, metadata, dummyController);
                const req = createRequest({
                    body: undefined,
                });
                const res = createResponse();
                const next = jest.fn();
                yield handler.handleRequest(req, res, next);
                expect(next).toBeCalledWith(expect.objectContaining({
                    statusCode: http_status_codes_1.default.BAD_REQUEST,
                }));
            });
        });
        it("returns BAD_REQUEST when a body fails validation", function () {
            return __awaiter(this, void 0, void 0, function* () {
                const method = jest.fn().mockReturnValue({});
                const metadata = createMethodMetadata({
                    request: {
                        schema: {
                            type: "object",
                            properties: {
                                foo: { type: "number" },
                            },
                        },
                    },
                });
                const handler = new method_handler_1.MethodHandler(method, metadata, dummyController);
                const req = createRequest({
                    body: {
                        foo: "This is not a number",
                    },
                });
                const res = createResponse();
                const next = jest.fn();
                yield handler.handleRequest(req, res, next);
                expect(next).toBeCalledWith(expect.objectContaining({
                    statusCode: http_status_codes_1.default.BAD_REQUEST,
                }));
            });
        });
    });
    describe("Arguments", function () {
        it("handles zero argument methods", function () {
            return __awaiter(this, void 0, void 0, function* () {
                const method = jest.fn().mockReturnValue({});
                const metadata = createMethodMetadata({});
                const handler = new method_handler_1.MethodHandler(method, metadata, dummyController);
                const req = createRequest({});
                const res = createResponse();
                const next = jest.fn();
                yield handler.handleRequest(req, res, next);
                expect(next).not.toBeCalled();
                expect(method).toBeCalled();
            });
        });
        describe("body", function () {
            it("provides the request body", function () {
                return __awaiter(this, void 0, void 0, function* () {
                    const body = { foo: 42 };
                    const method = jest.fn().mockReturnValue({});
                    const firstArg = {
                        type: "body",
                    };
                    const metadata = createMethodMetadata({
                        handlerArgs: [firstArg],
                    });
                    const handler = new method_handler_1.MethodHandler(method, metadata, dummyController);
                    const req = createRequest({
                        body,
                    });
                    const res = createResponse();
                    const next = jest.fn();
                    yield handler.handleRequest(req, res, next);
                    expect(next).not.toBeCalled();
                    expect(method).toBeCalledWith(body);
                });
            });
        });
        describe("pathParam", function () {
            it("provides the requested path param", function () {
                return __awaiter(this, void 0, void 0, function* () {
                    const method = jest.fn().mockReturnValue({});
                    const paramName = "testParam";
                    const paramValue = "This is the test param value";
                    const firstArg = {
                        type: "pathParam",
                        paramName,
                    };
                    const metadata = createMethodMetadata({
                        pathParams: {
                            [paramName]: {},
                        },
                        handlerArgs: [firstArg],
                    });
                    const handler = new method_handler_1.MethodHandler(method, metadata, dummyController);
                    const req = createRequest({
                        params: {
                            [paramName]: paramValue,
                        },
                    });
                    const res = createResponse();
                    const next = jest.fn();
                    yield handler.handleRequest(req, res, next);
                    expect(next).not.toBeCalled();
                    expect(method).toBeCalledWith(paramValue);
                });
            });
            it("returns NOT_FOUND when a required path param is not supplied", function () {
                return __awaiter(this, void 0, void 0, function* () {
                    const method = jest.fn().mockReturnValue({});
                    const paramName = "testParam";
                    const firstArg = {
                        type: "pathParam",
                        paramName,
                    };
                    const metadata = createMethodMetadata({
                        pathParams: {
                            [paramName]: {
                                required: true,
                            },
                        },
                        handlerArgs: [firstArg],
                    });
                    const handler = new method_handler_1.MethodHandler(method, metadata, dummyController);
                    const req = createRequest({
                        params: {},
                    });
                    const res = createResponse();
                    const next = jest.fn();
                    yield handler.handleRequest(req, res, next);
                    expect(next).toBeCalledWith(expect.objectContaining({
                        statusCode: http_status_codes_1.default.NOT_FOUND,
                    }));
                });
            });
            it("returns NOT_FOUND when the path param is invalid", function () {
                return __awaiter(this, void 0, void 0, function* () {
                    const method = jest.fn().mockReturnValue({});
                    const paramName = "testParam";
                    const paramValue = "This is the test param value";
                    const firstArg = {
                        type: "pathParam",
                        paramName,
                    };
                    const metadata = createMethodMetadata({
                        pathParams: {
                            [paramName]: {
                                schema: { type: "integer" },
                            },
                        },
                        handlerArgs: [firstArg],
                    });
                    const handler = new method_handler_1.MethodHandler(method, metadata, dummyController);
                    const req = createRequest({
                        params: {
                            [paramName]: paramValue,
                        },
                    });
                    const res = createResponse();
                    const next = jest.fn();
                    yield handler.handleRequest(req, res, next);
                    expect(next).toBeCalledWith(expect.objectContaining({
                        statusCode: http_status_codes_1.default.NOT_FOUND,
                    }));
                });
            });
            it("coerces the query param value where appropriate", function () {
                return __awaiter(this, void 0, void 0, function* () {
                    const method = jest.fn().mockReturnValue({});
                    const paramName = "testParam";
                    const paramValue = "42";
                    const expectedParamValue = 42;
                    const firstArg = {
                        type: "pathParam",
                        paramName,
                    };
                    const metadata = createMethodMetadata({
                        pathParams: {
                            [paramName]: {
                                schema: { type: "integer" },
                            },
                        },
                        handlerArgs: [firstArg],
                    });
                    const handler = new method_handler_1.MethodHandler(method, metadata, dummyController);
                    const req = createRequest({
                        params: {
                            [paramName]: paramValue,
                        },
                    });
                    const res = createResponse();
                    const next = jest.fn();
                    yield handler.handleRequest(req, res, next);
                    expect(next).not.toBeCalled();
                    expect(method).toBeCalledWith(expectedParamValue);
                });
            });
        });
        describe("queryParam", function () {
            it("provides the requested query param", function () {
                return __awaiter(this, void 0, void 0, function* () {
                    const method = jest.fn().mockReturnValue({});
                    const paramName = "testParam";
                    const paramValue = "This is the test param value";
                    const firstArg = {
                        type: "queryParam",
                        paramName,
                    };
                    const metadata = createMethodMetadata({
                        queryParams: {
                            [paramName]: {},
                        },
                        handlerArgs: [firstArg],
                    });
                    const handler = new method_handler_1.MethodHandler(method, metadata, dummyController);
                    const req = createRequest({
                        query: {
                            [paramName]: paramValue,
                        },
                    });
                    const res = createResponse();
                    const next = jest.fn();
                    yield handler.handleRequest(req, res, next);
                    expect(next).not.toBeCalled();
                    expect(method).toBeCalledWith(paramValue);
                });
            });
            it("returns BAD_REQUEST when a required query param is not supplied", function () {
                return __awaiter(this, void 0, void 0, function* () {
                    const method = jest.fn().mockReturnValue({});
                    const paramName = "testParam";
                    const firstArg = {
                        type: "queryParam",
                        paramName,
                    };
                    const metadata = createMethodMetadata({
                        queryParams: {
                            [paramName]: {
                                required: true,
                            },
                        },
                        handlerArgs: [firstArg],
                    });
                    const handler = new method_handler_1.MethodHandler(method, metadata, dummyController);
                    const req = createRequest({
                        query: {},
                    });
                    const res = createResponse();
                    const next = jest.fn();
                    yield handler.handleRequest(req, res, next);
                    expect(next).toBeCalledWith(expect.objectContaining({
                        statusCode: http_status_codes_1.default.BAD_REQUEST,
                    }));
                });
            });
            it("returns UNPROCESSABLE_ENTITY when the query param is invalid", function () {
                return __awaiter(this, void 0, void 0, function* () {
                    const method = jest.fn().mockReturnValue({});
                    const paramName = "testParam";
                    const paramValue = "This is the test param value";
                    const firstArg = {
                        type: "queryParam",
                        paramName,
                    };
                    const metadata = createMethodMetadata({
                        queryParams: {
                            [paramName]: {
                                schema: { type: "integer" },
                            },
                        },
                        handlerArgs: [firstArg],
                    });
                    const handler = new method_handler_1.MethodHandler(method, metadata, dummyController);
                    const req = createRequest({
                        query: {
                            [paramName]: paramValue,
                        },
                    });
                    const res = createResponse();
                    const next = jest.fn();
                    yield handler.handleRequest(req, res, next);
                    expect(next).toBeCalledWith(expect.objectContaining({
                        statusCode: http_status_codes_1.default.UNPROCESSABLE_ENTITY,
                    }));
                });
            });
            it("coerces the query param value where appropriate", function () {
                return __awaiter(this, void 0, void 0, function* () {
                    const method = jest.fn().mockReturnValue({});
                    const paramName = "testParam";
                    const paramValue = "42";
                    const expectedParamValue = 42;
                    const firstArg = {
                        type: "queryParam",
                        paramName,
                    };
                    const metadata = createMethodMetadata({
                        queryParams: {
                            [paramName]: {
                                schema: { type: "integer" },
                            },
                        },
                        handlerArgs: [firstArg],
                    });
                    const handler = new method_handler_1.MethodHandler(method, metadata, dummyController);
                    const req = createRequest({
                        query: {
                            [paramName]: paramValue,
                        },
                    });
                    const res = createResponse();
                    const next = jest.fn();
                    yield handler.handleRequest(req, res, next);
                    expect(next).not.toBeCalled();
                    expect(method).toBeCalledWith(expectedParamValue);
                });
            });
        });
        describe("request", function () {
            it("provides the request", function () {
                return __awaiter(this, void 0, void 0, function* () {
                    const method = jest.fn().mockReturnValue({});
                    const firstArg = {
                        type: "request",
                    };
                    const metadata = createMethodMetadata({
                        handlerArgs: [firstArg],
                    });
                    const handler = new method_handler_1.MethodHandler(method, metadata, dummyController);
                    const req = createRequest();
                    const res = createResponse();
                    const next = jest.fn();
                    yield handler.handleRequest(req, res, next);
                    expect(next).not.toBeCalled();
                    expect(method).toBeCalledWith(req);
                });
            });
        });
        describe("response", function () {
            it("provides the response", function () {
                return __awaiter(this, void 0, void 0, function* () {
                    const method = jest.fn().mockReturnValue({});
                    const firstArg = {
                        type: "response",
                    };
                    const metadata = createMethodMetadata({
                        handlerArgs: [firstArg],
                    });
                    const handler = new method_handler_1.MethodHandler(method, metadata, dummyController);
                    const req = createRequest();
                    const res = createResponse();
                    const next = jest.fn();
                    yield handler.handleRequest(req, res, next);
                    expect(next).not.toBeCalled();
                    expect(method).toBeCalledWith(res);
                });
            });
        });
    });
    it("calls the method with the controller context", function () {
        return __awaiter(this, void 0, void 0, function* () {
            let capturedInstance = undefined;
            const method = function () {
                capturedInstance = this;
                return {};
            };
            const metadata = createMethodMetadata();
            const handler = new method_handler_1.MethodHandler(method, metadata, dummyController);
            const req = createRequest({});
            const res = createResponse();
            const next = jest.fn();
            yield handler.handleRequest(req, res, next);
            expect(next).not.toBeCalled();
            expect(capturedInstance).toEqual(dummyController);
        });
    });
    it("supports promise-returning methods", function () {
        return __awaiter(this, void 0, void 0, function* () {
            const result = { foo: 42 };
            const method = jest.fn().mockReturnValue(Promise.resolve(result));
            const metadata = createMethodMetadata();
            const handler = new method_handler_1.MethodHandler(method, metadata, dummyController);
            const req = createRequest({});
            const res = createResponse();
            const next = jest.fn();
            yield handler.handleRequest(req, res, next);
            expect(next).not.toBeCalled();
            expect(res.send).toBeCalledWith(result);
        });
    });
    it("supports non-promise-returning methods", function () {
        return __awaiter(this, void 0, void 0, function* () {
            const result = { foo: 42 };
            const method = jest.fn().mockReturnValue(result);
            const metadata = createMethodMetadata();
            const handler = new method_handler_1.MethodHandler(method, metadata, dummyController);
            const req = createRequest({});
            const res = createResponse();
            const next = jest.fn();
            yield handler.handleRequest(req, res, next);
            expect(next).not.toBeCalled();
            expect(res.send).toBeCalledWith(result);
        });
    });
    describe("Response Validation", function () {
        it("Allows a non-validated response", function () {
            return __awaiter(this, void 0, void 0, function* () {
                const statusCode = 123;
                const methodResult = method_result_1.result({ foo: 42 }).status(statusCode);
                const method = jest.fn().mockReturnValue(methodResult);
                const metadata = createMethodMetadata({
                    responses: {
                        [statusCode + 1]: {
                            schema: { type: "null" },
                        },
                    },
                });
                const handler = new method_handler_1.MethodHandler(method, metadata, dummyController);
                const req = createRequest({});
                const res = createResponse();
                const next = jest.fn();
                yield handler.handleRequest(req, res, next);
                expect(next).not.toBeCalled();
                expect(res.send).toBeCalled();
            });
        });
        it("passes a validated response", function () {
            return __awaiter(this, void 0, void 0, function* () {
                const statusCode = 123;
                const methodResult = method_result_1.result({ foo: 42 }).status(statusCode);
                const method = jest.fn().mockReturnValue(methodResult);
                const metadata = createMethodMetadata({
                    responses: {
                        [statusCode]: {
                            schema: {
                                type: "object",
                                properties: { foo: { type: "integer" } },
                            },
                        },
                    },
                });
                const handler = new method_handler_1.MethodHandler(method, metadata, dummyController);
                const req = createRequest({});
                const res = createResponse();
                const next = jest.fn();
                yield handler.handleRequest(req, res, next);
                expect(next).not.toBeCalled();
                expect(res.send).toBeCalled();
            });
        });
        it("responds to an invalid response with INTERNAL_SERVER_ERROR", function () {
            return __awaiter(this, void 0, void 0, function* () {
                const statusCode = 123;
                const methodResult = method_result_1.result({ foo: "This is not an integer" }).status(statusCode);
                const method = jest.fn().mockReturnValue(methodResult);
                const metadata = createMethodMetadata({
                    responses: {
                        [statusCode]: {
                            schema: {
                                type: "object",
                                properties: { foo: { type: "integer" } },
                            },
                        },
                    },
                });
                const handler = new method_handler_1.MethodHandler(method, metadata, dummyController);
                const req = createRequest({});
                const res = createResponse();
                const next = jest.fn();
                yield handler.handleRequest(req, res, next);
                // We throw a regular (private) error for response schema violations.
                expect(next).toBeCalled();
                expect(next.mock.calls[0][0]).toBeInstanceOf(Error);
            });
        });
    });
    describe("Response Transmission", function () {
        it("supports string responses", function () {
            return __awaiter(this, void 0, void 0, function* () {
                const response = "This is the response";
                const method = jest.fn().mockReturnValue(response);
                const metadata = createMethodMetadata();
                const handler = new method_handler_1.MethodHandler(method, metadata, dummyController);
                const req = createRequest();
                const res = createResponse();
                const next = jest.fn();
                yield handler.handleRequest(req, res, next);
                expect(next).not.toBeCalled();
                expect(res.send).toBeCalledWith(response);
            });
        });
        it("supports array responses", function () {
            return __awaiter(this, void 0, void 0, function* () {
                const response = [1, 2, 3];
                const method = jest.fn().mockReturnValue(response);
                const metadata = createMethodMetadata();
                const handler = new method_handler_1.MethodHandler(method, metadata, dummyController);
                const req = createRequest();
                const res = createResponse();
                const next = jest.fn();
                yield handler.handleRequest(req, res, next);
                expect(next).not.toBeCalled();
                expect(res.send).toBeCalledWith(response);
            });
        });
        it("supports object responses", function () {
            return __awaiter(this, void 0, void 0, function* () {
                const response = { foo: true };
                const method = jest.fn().mockReturnValue(response);
                const metadata = createMethodMetadata();
                const handler = new method_handler_1.MethodHandler(method, metadata, dummyController);
                const req = createRequest();
                const res = createResponse();
                const next = jest.fn();
                yield handler.handleRequest(req, res, next);
                expect(next).not.toBeCalled();
                expect(res.send).toBeCalledWith(response);
            });
        });
        it("supports string responses through result()", function () {
            return __awaiter(this, void 0, void 0, function* () {
                const response = "This is the response";
                const method = jest.fn().mockReturnValue(method_result_1.result(response));
                const metadata = createMethodMetadata();
                const handler = new method_handler_1.MethodHandler(method, metadata, dummyController);
                const req = createRequest();
                const res = createResponse();
                const next = jest.fn();
                yield handler.handleRequest(req, res, next);
                expect(next).not.toBeCalled();
                expect(res.send).toBeCalledWith(response);
            });
        });
        it("supports array responses through result()", function () {
            return __awaiter(this, void 0, void 0, function* () {
                const response = [1, 2, 3];
                const method = jest.fn().mockReturnValue(method_result_1.result(response));
                const metadata = createMethodMetadata();
                const handler = new method_handler_1.MethodHandler(method, metadata, dummyController);
                const req = createRequest();
                const res = createResponse();
                const next = jest.fn();
                yield handler.handleRequest(req, res, next);
                expect(next).not.toBeCalled();
                expect(res.send).toBeCalledWith(response);
            });
        });
        it("supports object responses through result()", function () {
            return __awaiter(this, void 0, void 0, function* () {
                const response = { foo: true };
                const method = jest.fn().mockReturnValue(method_result_1.result(response));
                const metadata = createMethodMetadata();
                const handler = new method_handler_1.MethodHandler(method, metadata, dummyController);
                const req = createRequest();
                const res = createResponse();
                const next = jest.fn();
                yield handler.handleRequest(req, res, next);
                expect(next).not.toBeCalled();
                expect(res.send).toBeCalledWith(response);
            });
        });
        it("sets headers according to the response", function () {
            return __awaiter(this, void 0, void 0, function* () {
                const headerName1 = "Header1";
                const headerValue1 = "Foo";
                const headerName2 = "Header2";
                const headerValue2 = "Bar";
                const methodResult = method_result_1.result({ foo: 42 })
                    .header(headerName1, headerValue1)
                    .header(headerName2, headerValue2);
                const method = jest.fn().mockReturnValue(Promise.resolve(methodResult));
                const metadata = createMethodMetadata();
                const handler = new method_handler_1.MethodHandler(method, metadata, dummyController);
                const req = createRequest({});
                const res = createResponse();
                const next = jest.fn();
                yield handler.handleRequest(req, res, next);
                expect(next).not.toBeCalled();
                expect(res.setHeader).toBeCalledWith(headerName1, headerValue1);
                expect(res.setHeader).toBeCalledWith(headerName2, headerValue2);
            });
        });
        it("sets status code according to the response", function () {
            return __awaiter(this, void 0, void 0, function* () {
                const statusCode = http_status_codes_1.default.IM_A_TEAPOT;
                const methodResult = method_result_1.result({ foo: 42 }).status(statusCode);
                const method = jest.fn().mockReturnValue(Promise.resolve(methodResult));
                const metadata = createMethodMetadata();
                const handler = new method_handler_1.MethodHandler(method, metadata, dummyController);
                const req = createRequest({});
                const res = createResponse();
                const next = jest.fn();
                yield handler.handleRequest(req, res, next);
                expect(next).not.toBeCalled();
                expect(res.status).toBeCalledWith(statusCode);
            });
        });
        it("sets cookies according to the response", function () {
            return __awaiter(this, void 0, void 0, function* () {
                const cookieName1 = "Cookie1";
                const cookieValue1 = "Foo";
                const cookieName2 = "Header2";
                const cookieValue2 = "Bar";
                const cookieSettings2 = {
                    domain: "www.foobar.com",
                    path: "/foo",
                    expires: false,
                };
                const methodResult = method_result_1.result({ foo: 42 })
                    .cookie(cookieName1, cookieValue1)
                    .cookie(cookieName2, cookieValue2, cookieSettings2);
                const method = jest.fn().mockReturnValue(Promise.resolve(methodResult));
                const metadata = createMethodMetadata();
                const handler = new method_handler_1.MethodHandler(method, metadata, dummyController);
                const req = createRequest({});
                const res = createResponse();
                const next = jest.fn();
                yield handler.handleRequest(req, res, next);
                expect(next).not.toBeCalled();
                expect(res.cookie).toBeCalledWith(cookieName1, cookieValue1, {});
                expect(res.cookie).toBeCalledWith(cookieName2, cookieValue2, cookieSettings2);
            });
        });
        it("sends the raw result", function () {
            return __awaiter(this, void 0, void 0, function* () {
                const methodResult = { foo: 42 };
                const method = jest.fn().mockReturnValue(Promise.resolve(methodResult));
                const metadata = createMethodMetadata();
                const handler = new method_handler_1.MethodHandler(method, metadata, dummyController);
                const req = createRequest({});
                const res = createResponse();
                const next = jest.fn();
                yield handler.handleRequest(req, res, next);
                expect(next).not.toBeCalled();
                expect(res.send).toBeCalledWith(methodResult);
            });
        });
        it("sends the result when result() is used", function () {
            return __awaiter(this, void 0, void 0, function* () {
                const rawResult = { foo: 42 };
                const methodResult = method_result_1.result(rawResult).status(http_status_codes_1.default.IM_A_TEAPOT);
                const method = jest.fn().mockReturnValue(Promise.resolve(methodResult));
                const metadata = createMethodMetadata();
                const handler = new method_handler_1.MethodHandler(method, metadata, dummyController);
                const req = createRequest({});
                const res = createResponse();
                const next = jest.fn();
                yield handler.handleRequest(req, res, next);
                expect(next).not.toBeCalled();
                expect(res.send).toBeCalledWith(rawResult);
            });
        });
    });
});
function createRequest(opts) {
    if (!opts)
        opts = {};
    return {
        body: opts.body,
        params: opts.params || {},
        query: opts.query || {},
    };
}
function createResponse() {
    const res = {};
    res.setHeader = jest.fn().mockReturnValue(res);
    res.cookie = jest.fn().mockReturnValue(res);
    res.status = jest.fn().mockReturnValue(res);
    res.send = jest.fn().mockReturnValue(res);
    return res;
}
function createMethodMetadata(metadata) {
    return Object.assign({ method: "GET" }, metadata);
}
//# sourceMappingURL=method-handler.spec.js.map