"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const express_1 = require("express");
const path_1 = __importDefault(require("path"));
const body_parser_1 = __importDefault(require("body-parser"));
const metadata_1 = require("../metadata");
const controller_utils_1 = require("../controller-utils");
const method_handler_1 = require("./method-handler");
function createControllerRoute(...controllers) {
    const router = express_1.Router();
    router.use(body_parser_1.default.json());
    for (const controller of controllers) {
        linkControllerToRoute(controller, router);
    }
    return router;
}
exports.createControllerRoute = createControllerRoute;
function linkControllerToRoute(controller, route) {
    const controllerMetadata = metadata_1.getControllerMetadata(controller.constructor);
    if (!controllerMetadata) {
        throw new Error(`Controller "${controller.constructor.name}" does not have a @controller annotation.`);
    }
    const methods = controller_utils_1.getControllerMethods(controller);
    for (const { metadata: methodMetadata, method } of methods) {
        linkControllerMethodToRoute(controller, controllerMetadata, method, methodMetadata, route);
    }
}
function linkControllerMethodToRoute(controller, controllerMetadata, method, methodMetadata, route) {
    const methodHandler = new method_handler_1.MethodHandler(method, methodMetadata, controller);
    // handleRequest is pre-bound by MethodHandler
    const handler = methodHandler.handleRequest;
    const path = path_1.default.posix.join(controllerMetadata.path || "/", methodMetadata.path || "/");
    switch (methodMetadata.method) {
        case "GET":
            route.get(path, handler);
            break;
        case "POST":
            route.post(path, handler);
            break;
        case "PUT":
            route.put(path, handler);
            break;
        case "PATCH":
            route.patch(path, handler);
            break;
        case "DELETE":
            route.delete(path, handler);
            break;
        case "TRACE":
            route.trace(path, handler);
            break;
        case "CONNECT":
            route.connect(path, handler);
            break;
        default:
            throw new Error(`Unknown method ${methodMetadata.method} for controller function ${method.name}.`);
    }
}
//# sourceMappingURL=route-factory.js.map